import os


def	all_folders_files(path):
    list0 = os.listdir(path)
    list_dir = []
    list_file = []
    for i in list0:
        if os.path.isdir(os.path.join(path,i)):
            list_dir.append(i)
        else:
            list_file.append(i)
    return list_dir, list_file
    
  
  
def all_files(file_path):
    list=[]
    for curDir, dirs, files in os.walk(file_path):

        if len(files)>0:
            path=[os.path.join(curDir,i) for i in files]
            for j in path:
                list.append(j)
    return list


def path_to_str(path):  # 这个也可以集成函数
    # 先取得文件名路径
    normpath = os.path.normpath(path)  # 转义为通用路径格式
    filepath, _ = os.path.split(normpath)
    Separator = os.sep  # os.sep根据你的平台自动使用分隔符
    part = filepath.split(Separator)  # 字符串根据分隔符分割得到列表
    pathallpart = "-".join(part)  # 第一个往往是.，我们用的都是相对路径所以要去掉
    return pathallpart



import os
import shutil
from wjj.path import all_files

def copyfile(srcfile, dstpath):  # 子函数
    if not os.path.isfile(srcfile):
        print("%s not exist!" % (srcfile))
    else:
        fpath, fname = os.path.split(srcfile)  # 分离文件名和路径
        if not os.path.exists(dstpath):
            os.makedirs(dstpath)
        shutil.copy(srcfile, os.path.join(dstpath, fname))  # 复制文件

def copy_deep_shortname(rootpath, shotnamelist, copypath):
    file_path = all_files(rootpath)
    for i in file_path:
        filepath, tmpfilename = os.path.split(i)
        shotname, extension = os.path.splitext(tmpfilename)
        if shotname in shotnamelist:
            copyfile(i, copypath)


def delete_deep_shortname(path,shotnamelist):#主函数
    file_path=all_files(path)
    for i in file_path:
        filepath, tmpfilename = os.path.split(i)  # 获取目录，获取文件名
        shotname, extension = os.path.splitext(tmpfilename)  # 获取短名，获取后缀
        if shotname in shotnamelist:
            print("已经删除",i)
            os.remove(i)


import setuptools

with open("README.md", "r",encoding='utf-8') as fh:
    long_description = fh.read()

setuptools.setup(
    name="wjj", # 模块名称
    version = "0.1.2", # 当前版本
    author="JJWang", # 作者
    author_email="jj.wang2@siat.ac.cn", # 作者邮箱
    description="常用函数集成", # 简短介绍
    long_description=long_description, # 模块详细介绍
    long_description_content_type="text/markdown", # 模块详细介绍格式
    packages=setuptools.find_packages(), # 自动找到项目中导入的模块
    # 模块相关的元数据(更多描述信息)
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    # 依赖模块
)



